@@ -94,8 +94,7 @@ void KCMPlymouth::getNewStuff()
                 return;
             }
 
-            const QUrl previewUrl(entry.previewUrl(KNSCore::EntryInternal::PreviewBig1));
-            KIO::file_copy(previewUrl, QUrl::fromLocalFile(entry.installedFiles().first() + ".png"), -1, KIO::Overwrite | KIO::HideProgressInfo);
+            KIO::file_copy(entry.previewUrl(KNSCore::EntryInternal::PreviewBig1), QUrl::fromLocalFile(entry.installedFiles().first() + ".png"), -1,  KIO::Overwrite | KIO::HideProgressInfo);
         });
     }
     m_newStuffDialog.data()->show();
@@ -184,6 +183,7 @@ void KCMPlymouth::save()
     KAuth::Action action(QStringLiteral("org.kde.kcontrol.kcmplymouth.save"));
     action.setHelperId("org.kde.kcontrol.kcmplymouth");
     action.setArguments(helperargs);
+    action.setTimeout(60000);
 
     KAuth::ExecuteJob *job = action.execute();
     bool rc = job->exec();
